@@ -213,7 +213,8 @@
 ##'
 ##' # list of coordinate tables
 ##' spOccList2 <- lapply(spOccList, function(x) st_coordinates(x))
-##' tamiasEPM <- createEPMgrid(spOccList, resolution = 100000, cellType = 'square')
+##' tamiasEPM <- createEPMgrid(spOccList2, resolution = 100000, cellType = 'square', 
+##' 	crs = st_crs(tamiasPolyList[[1]]))
 ##'
 ##' # single table of coordinates
 ##' spOccList3 <- spOccList2
@@ -224,12 +225,13 @@
 ##' spOccList3 <- do.call(rbind, spOccList3)
 ##' rownames(spOccList3) <- NULL
 ##' spOccList3[, "taxon"] <- as.character(spOccList3[, "taxon"])
-##' tamiasEPM <- createEPMgrid(spOccList, resolution = 100000, cellType = 'square')
+##' tamiasEPM <- createEPMgrid(spOccList3, resolution = 100000, cellType = 'square', 
+##' 	crs = st_crs(tamiasPolyList[[1]]))
 ##'
 ##' # a single labeled spatial object
 ##' spOccList4 <- st_as_sf(spOccList3[, c("taxon", "X", "Y")], coords = c("X","Y"),
 ##' crs = st_crs(spOccList[[1]]))
-##' tamiasEPM <- createEPMgrid(spOccList, resolution = 100000, cellType = 'square')
+##' tamiasEPM <- createEPMgrid(spOccList4, resolution = 100000, cellType = 'square')
 ##'}
 ##'
 ##'
@@ -276,7 +278,7 @@ createEPMgrid <- function(spDat, resolution = 50000, method = 'centroid', cellTy
 	
 	# single non-spatial data table
 	} else if (!inherits(spDat, c('sf', 'sfc')) & inherits(spDat, c('data.frame', 'matrix'))) {
-		if (all(c('taxon', 'x', 'y') %in% colnames(spDat)) | all(c('taxon', 'long', 'lat') %in% colnames(spDat))) {
+		if (all(c('taxon', 'x', 'y') %in% tolower(colnames(spDat))) | all(c('taxon', 'long', 'lat') %in% tolower(colnames(spDat)))) {
 			datType <- 'points'
 			if (!is.null(crs)) {
 				proj <- crs
